@@ -48,6 +48,8 @@
 #' landscape structure using the GRASS geographical information system.
 #' Landscape Ecology 7: 291-302.
 #'
+#' Based on C++ code from Project Nayuki (https://www.nayuki.io/page/smallest-enclosing-circle).
+#'
 #' @export
 lsm_l_circle_cv <- function(landscape, directions) UseMethod("lsm_l_circle_cv")
 
@@ -133,13 +135,11 @@ lsm_l_circle_cv.list <- function(landscape, directions = 8) {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_l_circle_cv_calc <- function(landscape, directions,
-                                 resolution = NULL, points = NULL) {
+lsm_l_circle_cv_calc <- function(landscape, directions, resolution = NULL) {
 
     circle_patch <- lsm_p_circle_calc(landscape,
                                       directions = directions,
-                                      resolution = resolution,
-                                      points = points)
+                                      resolution = resolution)
 
     # all values NA
     if (all(is.na(circle_patch$value))) {
