@@ -166,13 +166,20 @@ lsm_l_dcore_mn_calc <- function(landscape, directions, consider_boundary, edge_d
                                     edge_depth = edge_depth,
                                     points = points)
 
+    # all values NA
+    if (all(is.na(dcore_patch$value))) {
+        return(tibble::tibble(level = "landscape",
+                              class = as.integer(NA),
+                              id = as.integer(NA),
+                              metric = "dcore_mn",
+                              value = as.double(NA)))
+    }
+
     dcore_mn <- mean(dcore_patch$value)
 
-    tibble::tibble(
-        level = "landscape",
-        class = as.integer(NA),
-        id = as.integer(NA),
-        metric = "dcore_mn",
-        value = as.double(dcore_mn)
-    )
+    return(tibble::tibble(level = "landscape",
+                          class = as.integer(NA),
+                          id = as.integer(NA),
+                          metric = "dcore_mn",
+                          value = as.double(dcore_mn)))
 }
