@@ -140,14 +140,21 @@ lsm_l_gyrate_sd_calc <- function(landscape, directions,
                                       directions = directions,
                                       points = points)
 
+    # all values NA
+    if (all(is.na(gyrate_patch$value))) {
+        return(tibble::tibble(level = "landscape",
+                              class = as.integer(NA),
+                              id = as.integer(NA),
+                              metric = "gyrate_sd",
+                              value = as.double(NA)))
+    }
+
     gyrate_sd <- stats::sd(gyrate_patch$value)
 
-    tibble::tibble(
-        level = "landscape",
-        class = as.integer(NA),
-        id = as.integer(NA),
-        metric = "gyrate_sd",
-        value = as.double(gyrate_sd)
-    )
+    return(tibble::tibble(level = "landscape",
+                          class = as.integer(NA),
+                          id = as.integer(NA),
+                          metric = "gyrate_sd",
+                          value = as.double(gyrate_sd)))
 }
 
