@@ -22,8 +22,8 @@ test_that("get_patches can handle all raster inputs", {
 })
 
 test_that("get_patches labels the patches correctly", {
-    expect(length(unlist(get_unique_values(class_1_landscape_8))) == 9)
-    expect(length(unlist(get_unique_values(class_1_landscape_4))) == 11)
-    expect(length(which(class_1_landscape_4[[1]]@data@values == 6)) == 63)
-    expect(length(which(class_1_landscape_8[[1]]@data@values == 6)) == 14)
+    expect_true(length(unlist(get_unique_values(class_1_landscape_8))) == 9)
+    expect_true(length(unlist(get_unique_values(class_1_landscape_4))) == 11)
+    expect_true(length(which(class_1_landscape_4[[1]]@data@values == 6)) == 63)
+    expect_true(length(which(class_1_landscape_8[[1]]@data@values == 6)) == 14)
 })
